@@ -198,8 +198,8 @@ public final class Fraction
         long p1 = a0;
         long q1 = 1;
 
-        long p2 = 0;
-        long q2 = 1;
+        long p2;
+        long q2;
 
         int n = 0;
         boolean stop = false;
@@ -423,11 +423,23 @@ public final class Fraction
         return ZERO;
     }
 
+    /** {@inheritDoc} */
+    @Override
+    public boolean isZero() {
+        return numerator == 0;
+    }
+
     @Override
     public Fraction one() {
         return ONE;
     }
 
+    /** {@inheritDoc} */
+    @Override
+    public boolean isOne() {
+        return numerator == denominator;
+    }
+
     /**
      * Access the numerator as an {@code int}.
      *
@@ -898,13 +910,4 @@ public final class Fraction
         final int denS = Integer.signum(denominator);
         return (31 * (31 + numerator * numS) + denominator * denS) * numS * denS;
     }
-
-    /**
-     * Returns true if this fraction is zero.
-     *
-     * @return true if zero
-     */
-    private boolean isZero() {
-        return numerator == 0;
-    }
 }
